elephant.signal\_processing.cross\_correlation\_function
========================================================

.. currentmodule:: elephant.signal_processing

.. autofunction:: cross_correlation_function